@@ -13,7 +13,7 @@ compute_initial_estimate <- function(obj) {
                    verbose = FALSE, eval.loglik = FALSE)
             )
     if (obj$est$parameterization == "offset") { 
-      obj$est$theta <- init$coef 
+      obj$est$theta <- coef(init) 
       if (!is.null(obj$net$edge_loc)) { 
         obj$est$theta[obj$net$edge_loc] <- obj$est$theta[obj$net$edge_loc] + log(median(obj$net$clust_sizes))
       }
@@ -22,7 +22,7 @@ compute_initial_estimate <- function(obj) {
       }
       obj$est$theta_0 <- obj$est$theta 
     } else if (obj$est$parameterization == "size") { 
-      cur_theta <- init$coef 
+      cur_theta <- coef(init)
       which_canonical <- which(obj$net$etamap$canonical != 0)
       cur_theta[which_canonical] <- cur_theta[which_canonical] / log_fun(median(obj$net$clust_sizes))
       if (sum(obj$net$etamap$canonical == 0) > 0) {
@@ -38,7 +38,7 @@ compute_initial_estimate <- function(obj) {
       obj$est$theta <- cur_theta 
       obj$est$theta_0 <- obj$est$theta 
     } else {  
-      obj$est$theta <- init$coef
+      obj$est$theta <- coef(init)
       obj$est$theta_0 <- obj$est$theta 
     }
 
@@ -46,14 +46,15 @@ compute_initial_estimate <- function(obj) {
   } else {
     net <- reorder_block_matrix(obj$net$net_list)
     form <- as.formula(paste0("net ~ ", obj$net$terms)) 
-    model <- ergm_model(form, net) 
-    fixed_form   <- fix.curved(form, rep(0.25, length(model$etamap$canonical)))$formula
+    #model <- ergm_model(form, net) 
+    #fixed_form   <- fix.curved(form, rep(0.25, length(model$etamap$canonical)))$formula
     init <- suppressMessages(
-              ergm(fixed_form, estimate = "MPLE", constraints = ~ blockdiag("node_memb_group"),
+              ergm(form, estimate = "MPLE", constraints = ~ blockdiag("node_memb_group"),
                    verbose = FALSE, eval.loglik = FALSE)
             )
+    cur_theta <- coef(init) 
     if (obj$est$parameterization == "offset") {
-      obj$est$theta <- init$coef
+      obj$est$theta <- coef(init)
       if (!is.null(obj$net$edge_loc)) {
         obj$est$theta[obj$net$edge_loc] <- obj$est$theta[obj$net$edge_loc] + log(median(obj$net$clust_sizes))
       }
@@ -62,7 +63,6 @@ compute_initial_estimate <- function(obj) {
       }
       obj$est$theta_0 <- obj$est$theta 
     } else if (obj$est$parameterization == "size") { 
-      cur_theta <- init$coef
       which_canonical <- which(obj$net$etamap$canonical != 0)
       cur_theta[which_canonical] <- cur_theta[which_canonical] / log_fun(median(obj$net$clust_sizes))
       if (sum(obj$net$etamap$canonical == 0) > 0) {
@@ -78,33 +78,9 @@ compute_initial_estimate <- function(obj) {
       obj$est$theta <- cur_theta
       obj$est$theta_0 <- obj$est$theta
     } else {
-      obj$est$theta <- init$coef
-      obj$est$theta_0 <- obj$est$coef 
+      obj$est$theta <- cur_theta 
+      obj$est$theta_0 <- obj$est$theta 
     }
-    theta <- numeric(0)
-    num_curved_terms <- length(obj$net$model$etamap$curved)
-    curved_params <- numeric(0)
-    for (l in 1:num_curved_terms) {
-      add_base_param_loc <- obj$net$model$etamap$curved[[l]]$from[seq(1, length(obj$net$model$etamap$curved[[l]]$from), by = 2)] 
-      curved_params <- c(curved_params, add_base_param_loc) 
-    }
-    skip_flag <- FALSE
-    full_param_names <- get_coef_names(obj$net$model, FALSE)
-    iter <- 1
-    for (m in 1:length(full_param_names)) {
-      if ((m %in% curved_params) & !skip_flag) { 
-        theta <- c(theta, obj$est$theta[iter], 0.25)
-        iter <- iter + 1 
-        skip_flag <- TRUE
-      } else if (!skip_flag) {
-        theta <- c(theta, obj$est$theta[iter])
-        iter <- iter + 1 
-      } else { 
-        skip_flag <- FALSE
-      }
-    }
-    names(theta) <- full_param_names
-    obj$est$theta  <- obj$est$theta_0 <- theta
   }
 
   return(obj) 
