@@ -37,17 +37,26 @@ summary.mlergm <- function(object, ...) {
     cat("\n\n")
     cat("Monte Carlo MLE Results:\n")
     if ((object$parameterization == "offset") & ("edges" %in% names(object$theta))) {
-      cat("    Within-block edge parameter    =  edges  - log(Block size)\n")
+      cat("    Within-block edge parameter    =  edge parameter estimate   - log(block size)\n")
     } 
     if ((object$parameterization == "offset") & ("mutual" %in% names(object$theta))) { 
-      cat("    Within-block mutual parameter  =  mutual + log(Block size)\n")
+      cat("    Within-block mutual parameter  =  mutual parameter estimate + log(block size)\n")
     }
     if (object$parameterization == "size") { 
-      cat("    Within-block parameter = parameter * log n(k),   n(k) is the size of block k\n")
+      cat("    Within-block parameter  =  parameter estimate * log(block size)\n")
+      cat("        ** Excludes decay parameters for GW-terms\n") 
+      cat("    -----------------------------------------------------------------\n")
+      cat("    Between-block parameter =  parameter estimate * log(network size)\n")
+    }
+    if ((object$parameterization == "offset") & !is.character(object$between_theta)) { 
+      cat("    -------------------------------------------------------------------------------------------\n")
+      cat("    Between-block edge parameter   =  between-block edge parameter estimate * log(network size)\n")
     }
     cat("\n")
+    cat("Within-block model terms:")
+    cat("\n")
     theta_names <- names(object$theta)
-    max_char <- max(nchar(c(theta_names, "between edges", "between mutual")))
+    max_char <- max(nchar(c(theta_names, "between-block edges")))
     name_space <- paste(rep(" ", max_char), collapse = "")
     cat(name_space)
     cat("    Estimate   Std. Error    p-value    Sig.\n")
@@ -100,7 +109,7 @@ summary.mlergm <- function(object, ...) {
         cur_name <- names(object$between_theta)[i]
         cat(cur_name) 
         white_space <- paste(rep(" ", max_char - nchar(cur_name)), collapse = "")
-        cat("      ")
+        cat("     ")
         if (object$between_theta[i] >= 0) {
           cat("")
         }
@@ -143,7 +152,7 @@ summary.mlergm <- function(object, ...) {
     cat("BIC:  ")
     if (!is.null(object$bic)) { 
       cat(paste(round(object$bic, digits = 3)))
-      cat("\n* Note: BIC is based on the within-block model, and ignores the between-block model.")
+      cat("\n* Note: BIC is based on the within-block model")
     } else { 
       cat("Not estimated.")
     }
